@@ -297,6 +297,9 @@ class ClientApplication(Frame):
         self._prepare_debug_game()
 
     def _prepare_debug_game(self):
+        import os
+        print os.getcwd()
+
         # load game and add player
         stream = open('../maps/default.map', 'r')
         game_map = pickle.load(stream)
